"""
Main interface for eks-auth service.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks_auth/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_eks_auth import (
        Client,
        EKSAuthClient,
    )

    session = Session()
    client: EKSAuthClient = session.client("eks-auth")
    ```
"""

from .client import EKSAuthClient

Client = EKSAuthClient

__all__ = ("Client", "EKSAuthClient")



"""
Type annotations for eks-auth service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks_auth/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_eks_auth.client import EKSAuthClient

    session = Session()
    client: EKSAuthClient = session.client("eks-auth")
    ```
"""

from __future__ import annotations

import sys
from typing import Any

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .type_defs import (
    AssumeRoleForPodIdentityRequestTypeDef,
    AssumeRoleForPodIdentityResponseTypeDef,
)

if sys.version_info >= (3, 9):
    from builtins import type as Type
    from collections.abc import Mapping
else:
    from typing import Mapping, Type
if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("EKSAuthClient",)


class Exceptions(BaseClientExceptions):
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ExpiredTokenException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    InvalidParameterException: Type[BotocoreClientError]
    InvalidRequestException: Type[BotocoreClientError]
    InvalidTokenException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceUnavailableException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]


class EKSAuthClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks-auth.html#EKSAuth.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks_auth/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        EKSAuthClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks-auth.html#EKSAuth.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks_auth/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks-auth/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks_auth/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks-auth/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks_auth/client/#generate_presigned_url)
        """

    def assume_role_for_pod_identity(
        self, **kwargs: Unpack[AssumeRoleForPodIdentityRequestTypeDef]
    ) -> AssumeRoleForPodIdentityResponseTypeDef:
        """
        The Amazon EKS Auth API and the <code>AssumeRoleForPodIdentity</code> action
        are only used by the EKS Pod Identity Agent.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks-auth/client/assume_role_for_pod_identity.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks_auth/client/#assume_role_for_pod_identity)
        """



"""
Type annotations for eks-auth service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks_auth/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_eks_auth.type_defs import AssumeRoleForPodIdentityRequestTypeDef

    data: AssumeRoleForPodIdentityRequestTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from datetime import datetime

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
else:
    from typing import Dict
if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict

__all__ = (
    "AssumeRoleForPodIdentityRequestTypeDef",
    "AssumeRoleForPodIdentityResponseTypeDef",
    "AssumedRoleUserTypeDef",
    "CredentialsTypeDef",
    "PodIdentityAssociationTypeDef",
    "ResponseMetadataTypeDef",
    "SubjectTypeDef",
)

class AssumeRoleForPodIdentityRequestTypeDef(TypedDict):
    clusterName: str
    token: str

class AssumedRoleUserTypeDef(TypedDict):
    arn: str
    assumeRoleId: str

class CredentialsTypeDef(TypedDict):
    sessionToken: str
    secretAccessKey: str
    accessKeyId: str
    expiration: datetime

class PodIdentityAssociationTypeDef(TypedDict):
    associationArn: str
    associationId: str

class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]

class SubjectTypeDef(TypedDict):
    namespace: str
    serviceAccount: str

class AssumeRoleForPodIdentityResponseTypeDef(TypedDict):
    subject: SubjectTypeDef
    audience: str
    podIdentityAssociation: PodIdentityAssociationTypeDef
    assumedRoleUser: AssumedRoleUserTypeDef
    credentials: CredentialsTypeDef
    ResponseMetadata: ResponseMetadataTypeDef
